scripts/django_cradmin/widgets/DateSelectorMonthWidget.jsx | django_cradmin API Document

# scripts/django_cradmin/widgets/DateSelectorMonthWidget.jsx

    import React from "react";
    import ReactDOM from "react-dom";
    import AbstractWidget from "ievv_jsbase/widget/AbstractWidget";
    import CradminDateSelectorMonth from "../components/CradminDateSelectorMonth";

    export default class DateSelectorMonthWidget extends AbstractWidget {
      constructor(element, widgetInstanceId) {
        super(element, widgetInstanceId);
        ReactDOM.render(
          <CradminDateSelectorMonth {...this.config} />,
          this.element
        );
      }

      destroy() {
        ReactDOM.unmountComponentAtNode(this.element);
      }

      useAfterInitializeAllWidgets() {
        return true;
      }

      afterInitializeAllWidgets() {
        new window.ievv_jsbase_core.SignalHandlerSingleton().send(`${this.config.signalNameSpace}.initializeValues`, null, (info) => {
          console.log(`I haz initialized stuffs!:\n\t${info}`);
        });
      }
    }